@@ -11,7 +11,7 @@
 //!
 //! * [Cookbooks](#cookbooks)
 //! * [Data structures](#data-structures)
-//!     - [DataFrame](#dtaframe)
+//!     - [DataFrame](#dataframe)
 //!     - [Series](#series)
 //!     - [ChunkedArray](#chunkedarray)
 //! * [SIMD](#simd)
@@ -51,7 +51,7 @@
 //! `ChunkedArray<T>` are wrappers around an arrow array, that can contain multiples chunks, e.g.
 //! `Vec<dyn ArrowArray>`. These are the root data structures of Polars, and implement many operations.
 //! Most operations are implemented by traits defined in [chunked_array::ops](crate::chunked_array::ops),
-//! or on the [ChunkedArray struct](crate::chunked_array::ops).
+//! or on the [ChunkedArray struct](crate::chunked_array::ChunkedArray).
 //!
 //! ## SIMD
 //! Polars / Arrow uses packed_simd to speed up kernels with SIMD operations. SIMD is an optional
@@ -133,7 +133,13 @@
 //!     - `reinterpret` - Utility to reinterpret bits to signed/unsigned
 //!     - `take_opt_iter` - Take from a Series with `Iterator<Item=Option<usize>>`
 //!     - `mode` - [Return the most occurring value(s)](crate::chunked_array::ops::ChunkUnique::mode)
+//!     - `cum_agg` - [cumsum, cummin, cummax aggregation](crate::chunked_array::ops::CumAgg)
+//!     - `rolling_window` [rolling window functions, like rolling_mean](crate::chunked_array::ops::ChunkWindow)
+//!     - `interpolate` [interpolate None values](crate::chunked_array::ops::Interpolate)
 //!     - `extract_jsonpath` - [Run jsonpath queries on Utf8Chunked](https://goessner.net/articles/JsonPath/)
+//!     - `list` - [List utils](crate::chunked_array::list::namespace)
+//!     - `rank` - Ranking algorithms.
+//!     - `moment` - kurtosis and skew statistics
 //! * `DataFrame` pretty printing (Choose one or none, but not both):
 //!     - `plain_fmt` - no overflowing (less compilation times)
 //!     - `pretty_fmt` - cell overflow (increased compilation times)
@@ -152,16 +158,14 @@
 //!
 //! | data type               | feature flag      |
 //! |-------------------------|-------------------|
-//! | Time64NanoSecondType    | dtype-time64-ns   |
-//! | DurationNanosecondType  | dtype-duration-ns |
-//! | DurationMillisecondType | dtype-duration-ms |
-//! | Date32Type              | dtype-date32      |
-//! | Date64Type              | dtype-date64      |
+//! | DateType                | dtype-date        |
+//! | DatetimeType            | dtype-datetime    |
+//! | TimeType                | dtype-time        |
 //! | Int8Type                | dtype-i8          |
 //! | Int16Type               | dtype-i16         |
 //! | UInt8Type               | dtype-u8          |
 //! | UInt16Type              | dtype-u16         |
-//! | UInt64Type              | dtype-u64         |
+//! | Categorical             | dtype-categorical |
 //!
 //!
 //! Or you can choose on of the preconfigured pre-sets.
@@ -193,13 +197,21 @@
 //! ```
 //! ## Config with ENV vars
 //!
-//! * `POLARS_PAR_SORT_BOUND` -> sets the lower bound of rows at which Polars will use a parallel sorting algorithm.
-//!                              Default is 1M rows.
+//! * `POLARS_FMT_NO_UTF8` -> use ascii tables in favor of utf8.
 //! * `POLARS_FMT_MAX_COLS` -> maximum number of columns shown when formatting DataFrames.
 //! * `POLARS_FMT_MAX_ROWS` -> maximum number of rows shown when formatting DataFrames.
 //! * `POLARS_TABLE_WIDTH` -> width of the tables used during DataFrame formatting.
 //! * `POLARS_MAX_THREADS` -> maximum number of threads used to initialize thread pool (on startup).
 //! * `POLARS_VERBOSE` -> print logging info to stderr
+//! * `POLARS_NO_PARTITION` -> Polars may choose to partition the groupby operaiton, based on data
+//!                            cardinality. Setting this env var will turn partitioned groupby's off
+//! * `POLARS_PARTITION_SAMPLE_FRAC` -> how large chunk of the dataset to sample to determine cardinality,
+//!                                     defaults to `0.001`
+//! * `POLARS_PARTITION_CARDINALITY_FRAC` -> at which (estimated) cardinality a partitioned groupby should run.
+//!                                          defaults to `0.005`, any higher cardinality will run default groupby.
+//! * `POLARS_ALLOW_EXTENSION` -> allows for `[ObjectChunked<T>]` to be used in arrow, opening up possibilities like using
+//!                               `T` in complex lazy expressions. However this does require `unsafe` code allow this.
+//!
 //!
 //! ## Compile for WASM
 //! To be able to pretty print a `DataFrame` in `wasm32-wasi` you need to patch the `prettytable-rs`
@@ -216,9 +228,9 @@
 pub mod docs;
 pub mod prelude;
 
-pub use polars_core::{
-    chunked_array, datatypes, doc, error, frame, functions, series, testing, toggle_string_cache,
-};
+#[cfg(feature = "dtype-categorical")]
+pub use polars_core::toggle_string_cache;
+pub use polars_core::{chunked_array, datatypes, doc, error, frame, functions, series, testing};
 
 pub use polars_core::apply_method_all_arrow_series;
 pub use polars_core::df;
